@@ -16,12 +16,11 @@ from motus.regresion_lineal import analisis_regresion_lineal as m_arl
 from motus.entropia_divergencia import entropia_divergencia as m_ed
 from motus.rutas_distancias import distancias as m_dist, rutas_vectoriales as m_rv
 from motus.graficador import cilindros as m_ci
-from motus.regiones_cuadriculadas import regiones_cuadriculadas as m_reg_cuad,\
+from motus.regiones_cuadriculadas import regiones_cuadriculadas as m_reg_cuad, \
     regiones_preferidas as m_reg_pref, matrices_recurrencia as m_recurr
 from motus.regresion_lineal import analisis_regresion_lineal as m_arl
 import motus.graficador.config_graficas as m_cg
 
-
 warnings.filterwarnings("error")
 
 matplotlib.use('TkAgg')
@@ -44,6 +43,8 @@ class Experimento:
         self.lista_ordenada_de_indices_mas_altos = None
         self.archivo_consecuencias = False
 
+        self.velocidades_promediadas = dict()
+        self.aceleraciones_promediadas = dict()
         self.entropias = dict()
         self.histogramas = dict()
         self.regresiones_lineales = dict()
@@ -146,13 +147,15 @@ class Experimento:
         self.posiciones_y = arreglo_posicion_y
 
         self.config_graficas = m_cg.ConfigGrafica()
-        self.procesador_reg_lineal = m_arl.ProcesamientoRegresionLineal()
+        self.procesador_regresion_lineal = m_arl.ProcesamientoRegresionLineal()
         self.rutas_vectoriales = m_rv.InformacionRutasVectoriales(posiciones_eje_x=self.posiciones_x,
                                                                   posiciones_eje_y=self.posiciones_y)
 
         self.tiempo = arreglo_tiempo
         self.samples = arreglo_samples
 
+        self.consecuencias = None
+
         print("Se encuentra la columna consecuences: ", self.archivo_consecuencias)
         if self.archivo_consecuencias is True:
             self.consecuencias = arreglo_consecuencias
@@ -192,11 +195,9 @@ class Experimento:
         self.distancia_minima_todos_objetos = None
 
         self.serie_velocidad = None
-        self.serie_velocidad_promediada = None
         self.velocidad_maxima = None
 
         self.serie_aceleracion = None
-        self.serie_aceleracion_promediada = None
         self.aceleracion_maxima = None
 
         self.arreglo_region_cuadriculada = None
@@ -229,6 +230,13 @@ class Experimento:
             raise Exception('Hay un dato en el eje Y que es mayor que la dimensión de la caja. Valor: ',
                             self.posiciones_y.max())
 
+    def regresa_tipo_arreglo(self, nombre_arreglo):
+        arreglos = {
+            "Velocidad": self.serie_velocidad,
+            "Aceleracion": self.serie_aceleracion
+        }
+        return arreglos[nombre_arreglo]
+
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
         valor = True
@@ -258,7 +266,7 @@ class Experimento:
 
         print("Cálculo de distancias...")
 
-        self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4 =  \
+        self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4 = \
             m_dist.calcula_distancias_a_objetos(self.posiciones_x, self.posiciones_y, self.lista_objetos_relevantes)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
@@ -304,59 +312,93 @@ class Experimento:
         self.serie_velocidad = m_vel.calcula_serie_velocidad(self.tiempo,
                                                              self.posiciones_x,
                                                              self.posiciones_y)
-        self.velocidad_maxima = round(round(self.serie_velocidad.max(), 3))
-
-        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                           categoria="velocidad",
-                                           serie=self.serie_velocidad)
-
-        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="histograma_velocidad",
-                                       datos=self.histogramas["velocidad"])
+        self.velocidad_maxima = round(self.serie_velocidad.max(), 3)
 
         self.serie_aceleracion = m_vel.calcula_serie_aceleracion(arreglo_tiempo=self.tiempo,
                                                                  serie_velocidad=self.serie_velocidad)
 
+        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
+                                           categoria="velocidad",
+                                           serie=self.serie_velocidad)
+
+        self.aceleracion_maxima = round(self.serie_aceleracion.max(), 3)
+
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="aceleracion",
                                            serie=self.serie_aceleracion)
 
+    def calcula_entropias(self, tamanio_vectores, traslape):
+
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="histograma_velocidad",
+                                       datos=self.histogramas["velocidad"])
+
+        m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
+                                                  categoria="aproximada_velocidad",
+                                                  datos=self.serie_velocidad,
+                                                  tamanio_vectorial=tamanio_vectores,
+                                                  traslape=traslape)
+
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_aceleracion",
                                        datos=self.histogramas["aceleracion"])
 
+        m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
+                                                  categoria="aproximada_aceleracion",
+                                                  datos=self.serie_aceleracion,
+                                                  tamanio_vectorial=tamanio_vectores,
+                                                  traslape=traslape)
+
     def calcula_velocidades_promediadas(self, cantidad_datos_promedio):
+        print("-------------------------------------------------------------")
+        print("Entro a calcular velocidades promediadas\n")
+        print("Serie de velocidad: ", self.serie_velocidad)
 
-        self.serie_velocidad_promediada = m_vel.obtener_arreglo_promediado(self.serie_velocidad,
-                                                                           cantidad_datos_promedio)
+        serie_velocidad_promediada = m_vel.obtener_arreglo_promediado(self.serie_velocidad,
+                                                                      cantidad_datos_promedio)
+
+        m_vel.agrega_categoria_velocidad_aceleracion_promediados(diccionario_vel_acel_prom=
+                                                                 self.velocidades_promediadas,
+                                                                 datos=serie_velocidad_promediada,
+                                                                 promedio=cantidad_datos_promedio)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                           categoria="velocidad_promediada",
-                                           serie=self.serie_velocidad)
+                                           categoria="velocidad_promediada_" + str(cantidad_datos_promedio),
+                                           serie=serie_velocidad_promediada)
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="histograma_velocidad_promediada",
-                                       datos=self.histogramas["velocidad_promediada"])
+                                       categoria="histograma_velocidad_promediada_" + str(cantidad_datos_promedio),
+                                       datos=self.histogramas["velocidad_promediada_" + str(cantidad_datos_promedio)])
+
+        print("-------------------------------------------------------------")
+        print("Entro a calcular aceleracion promediada\n")
+        print("Serie de aceleracion: ", self.serie_aceleracion)
+
+        serie_aceleracion_promediada = m_vel.obtener_arreglo_promediado(self.serie_aceleracion,
+                                                                        cantidad_datos_promedio)
+
+        m_vel.agrega_categoria_velocidad_aceleracion_promediados(diccionario_vel_acel_prom=
+                                                                 self.aceleraciones_promediadas,
+                                                                 datos=serie_aceleracion_promediada,
+                                                                 promedio=cantidad_datos_promedio)
 
-        self.serie_aceleracion_promediada = m_vel.obtener_arreglo_promediado(self.serie_aceleracion,
-                                                                             cantidad_datos_promedio)
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                           categoria="aceleracion_promediada",
-                                           serie=self.serie_velocidad)
+                                           categoria="aceleracion_promediada_" + str(cantidad_datos_promedio),
+                                           serie=serie_aceleracion_promediada)
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="histograma_aceleracion_promediada",
-                                       datos=self.histogramas["aceleracion_promediada"])
+                                       categoria="histograma_aceleracion_promediada_" + str(cantidad_datos_promedio),
+                                       datos=self.histogramas["aceleracion_promediada_" + str(cantidad_datos_promedio)])
 
     def calcula_regiones_cuadriculadas(self):
 
         self.arreglo_region_cuadriculada, self.matriz_cuadriculada = \
-            m_reg_cuad.calcula_regiones_preferidas(tiempos=self.tiempo,
-                                                   serie_posiciones_x=self.posiciones_x,
-                                                   serie_posiciones_y=self.posiciones_y,
-                                                   cantidad_filas=self.cantidad_filas,
-                                                   cantidad_columnas=self.cantidad_columnas,
-                                                   dimension_caja=self.dimension_caja)
+            m_reg_cuad.calcula_regiones_cuadriculadas(tiempos=self.tiempo,
+                                                      serie_posiciones_x=self.posiciones_x,
+                                                      serie_posiciones_y=self.posiciones_y,
+                                                      cantidad_filas=self.cantidad_filas,
+                                                      cantidad_columnas=self.cantidad_columnas,
+                                                      dimension_caja=self.dimension_caja)
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones",
@@ -384,9 +426,20 @@ class Experimento:
             m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada,
                                                      region_importante=lista_indices)
 
-    def calcula_matrices_solo_regiones_preferidas(self):
+    def calcula_matrices_solo_regiones_preferidas(self, regiones_preferidas):
 
         print("Se inicia el procesamiento de las matrices con regiones preferidas")
+
+        self.regiones_preferidas = regiones_preferidas
+        total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
+        self.regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
+                                                                                 sublista=regiones_preferidas)
+
+        print("Regiones preferidas: ", self.regiones_preferidas)
+        print("Regiones no preferidas: ", self.regiones_no_preferidas)
+
+        print("--------------------------------------------------------------------------------")
+
         matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
         print("Se toma matriz cuadriculada", matriz_cuadriculada)
 
@@ -827,10 +880,16 @@ class Experimento:
             plt.scatter(self.tiempo, self.serie_velocidad, s=1)
 
         elif nombre_grafica == 'vel_prom':
-            print("Entro a vel_prom")
-            longitud_serie_velocidad_promediada = len(self.serie_velocidad_promediada)
+            print("Entro a vel_prom\n")
+
+            promedio = config_grafica.regresa_config_grafica_vel_acel_prom()
+            print("Promedio elegido: ", promedio)
+            velocidad_promediada = self.velocidades_promediadas[str(promedio)]
+            print("Velocidad promediada: ", velocidad_promediada)
+
+            longitud_serie_velocidad_promediada = len(velocidad_promediada)
             tiempo = np.linspace(0, longitud_serie_velocidad_promediada, longitud_serie_velocidad_promediada)
-            plt.scatter(tiempo, self.serie_velocidad_promediada, s=1)
+            plt.scatter(tiempo, velocidad_promediada, s=1)
 
         elif nombre_grafica == 'vel_hist':
             print("Entro a vel_hist")
@@ -844,13 +903,14 @@ class Experimento:
 
         elif nombre_grafica == 'acel_prom':
 
-            # Se hace el cálculo de la velocidad en cada momento del tiempo
-            # v_{t-1} = [((x_i - x_{i-1})^2 + (y_i - y_{i-1})^2)^(1/2)]/0.2
-            # y se grafica sobre el tiempo.
             print("Entro a acelPrm")
-            longitud_serie_aceleracion_promediada = len(self.serie_aceleracion_promediada)
+
+            promedio = config_grafica.regresa_config_grafica_vel_acel_prom()
+            aceleracion_promediada = self.aceleraciones_promediadas[str(promedio)]
+
+            longitud_serie_aceleracion_promediada = len(aceleracion_promediada)
             tiempo = np.linspace(0, longitud_serie_aceleracion_promediada, longitud_serie_aceleracion_promediada)
-            plt.scatter(tiempo, self.serie_aceleracion_promediada, s=1)
+            plt.scatter(tiempo, aceleracion_promediada, s=1)
 
         # elif grafica == 'distPeso':
         #    print("Entro a distPeso")
@@ -961,28 +1021,20 @@ class Experimento:
 
             print("Entro a regresión lineal")
 
-            tipo_regresion_lineal, brinco_temporal, longitud_serie_tiempo = \
-                config_grafica.regresa_config_grafica_regresion_lineal()
+            nombre_regresion_lineal = config_grafica.regresa_config_grafica_regresion_lineal()
+            print("Nombre_regresion_lineal:", nombre_regresion_lineal)
+            regresion_lineal_elegida = self.regresiones_lineales[nombre_regresion_lineal]
+            print("Diccionario:", regresion_lineal_elegida)
+            print("---------------------------------------------------------------")
+            indices_tiempo = regresion_lineal_elegida["indices_tiempo"]
+            series_tiempo = regresion_lineal_elegida["series_tiempo"]
+            resultados = regresion_lineal_elegida["resultados"]
+            pendientes = regresion_lineal_elegida["pendientes"]
 
-            print("Tipo regresion lineal: ", tipo_regresion_lineal)
-            print("Brinco temporal: ", brinco_temporal)
-            print("Longitud Serie Tiempo: ", longitud_serie_tiempo)
-
-            if tipo_regresion_lineal == "Velocidad":
-                print("Caso Velocidad")
-                arreglo_series_tiempo = np.array(self.serie_velocidad)
-            elif tipo_regresion_lineal == "Aceleración":
-                print("Caso aceleración")
-                arreglo_series_tiempo = np.array(self.serie_aceleracion)
-
-            print("Arreglo series tiempo: ", arreglo_series_tiempo)
-
-            indices_tiempo, series_tiempo = m_arl.generar_series_tiempo(lista_a_procesar=arreglo_series_tiempo,
-                                                                      brinco_temporal=brinco_temporal,
-                                                                      longitud_ventana_tiempo=longitud_serie_tiempo)
-
-            resultados =m_arl.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
-                                                                         series_tiempo=series_tiempo)
+            print("Indices de tiempo:", indices_tiempo)
+            print("Series_tiempo:", series_tiempo)
+            print("Resultados:", resultados)
+            print("Pendientes:", pendientes)
 
             for indice in range(0, len(indices_tiempo)):
                 plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue', s=1)
@@ -1243,7 +1295,7 @@ class Experimento:
 
             self.matriz_cuadriculada_solo_regiones_preferidas = \
                 m_reg_pref.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
-                                                                     regiones_preferidas)
+                                                           regiones_preferidas)
             self.matriz_cuadriculada_solo_regiones_preferidas = \
                 np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
 
@@ -1335,12 +1387,12 @@ class Experimento:
             print("Regiones preferidas: ", regiones_preferidas)
             total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
             regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
-                                                                        sublista=regiones_preferidas)
+                                                                                sublista=regiones_preferidas)
             print("Regiones no preferidas: ", regiones_no_preferidas)
 
             self.matriz_cuadriculada_solo_regiones_no_preferidas = \
                 m_reg_pref.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
-                                                   regiones_no_preferidas)
+                                                           regiones_no_preferidas)
             self.matriz_cuadriculada_solo_regiones_no_preferidas = \
                 np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
 
